﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GameOfLife.Commands
{
    /// <summary>
    /// A command for clearing the board.
    /// </summary>
    internal class ClearCommand : Command
    {
        /// <summary>
        /// The name of this command is "clear".
        /// </summary>
        public string CommandText
        {
            get { return "clear"; }
        }

        /// <summary>
        /// Executes this command, clearing the board.
        /// </summary>
        /// <param name="grid"></param>
        /// <param name="parameters"></param>
        /// <returns></returns>
        public bool Execute(Grid grid, string[] parameters)
        {
            // If the user tried to give parameters for this command,
            // error out.
            if (parameters.Length != 1)
            {
                Console.ForegroundColor = ConsoleColor.Red;
                Console.WriteLine("Error executing 'clear' command. " +
                    "Clear must not have any parameters.");
                Console.ForegroundColor = ConsoleColor.White;
                return false;
            }

            grid.Clear();

            return true;
        }

        /// <summary>
        /// Returns help text for this command.
        /// </summary>
        public string HelpText
        {
            get
            {
                string text = "";
                text += "clear:\n";
                text += "    Empties entire board.\n";
                text += "    Usage: clear";
                return text;
            }
        }
    }
}
