﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GameOfLife.Commands
{
    /// <summary>
    /// An interface that any command in the Game of Life must follow to be
    /// usable by the system.
    /// </summary>
    internal interface Command
    {
        /// <summary>
        /// A string representing the name of the command, which will be used
        /// by the command interpreter to select this command.
        /// </summary>
        string CommandText { get; }

        /// <summary>
        /// Actually executes the command, given the grid to operate on,
        /// and a list of parameters (including the name of the command) that
        /// were used to execute the command.
        /// </summary>
        bool Execute(Grid grid, string[] parameters);

        /// <summary>
        /// Returns help text that should be displayed when the user wants 
        /// help about this particular command/tool.
        /// </summary>
        string HelpText { get; }
    }
}
