﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GameOfLife.Commands
{
    /// <summary>
    /// A command that is used to turn grid drawing on or off. The grid helps
    /// you see the rows and columns better, but it might also get in the way.
    /// This provides the option to turn it on and off.
    /// </summary>
    internal class GridCommand : Command
    {
        /// <summary>
        /// Returns the name of this command.
        /// </summary>
        public string CommandText
        {
            get { return "grid"; }
        }

        /// <summary>
        /// Executes the command, turning the grid on or off as requested.
        /// </summary>
        public bool Execute(Grid grid, string[] parameters)
        {
            if (parameters.Length != 2)
            {
                Console.ForegroundColor = ConsoleColor.Red;
                Console.WriteLine("Error executing grid command. This command must include the word");
                Console.WriteLine("'on' or 'off' as the first parameter.");
                Console.WriteLine("\n  Examples: 'grid on' will draw the grid.");
                Console.WriteLine("\n            'grid off' will turn off grid drawing.");
                Console.ForegroundColor = ConsoleColor.White;
                return false;
            }

            try
            {
                bool turnOn = true;
                if (parameters[1] == "on") { turnOn = true; }
                else if (parameters[1] == "off") { turnOn = false; }
                else throw new Exception("Error interpreting first parameter. Must be 'on' or 'off'.");

                grid.ShowGrid = turnOn;

                return true;
            }
            catch (Exception e)
            {
                Console.ForegroundColor = ConsoleColor.Red;
                Console.WriteLine(e.Message);
                Console.ForegroundColor = ConsoleColor.White;
                return false;
            }
        }

        /// <summary>
        /// Returns help text for this command.
        /// </summary>
        public string HelpText
        {
            get
            {
                string text = "";
                text += "grid:\n";
                text += "    Turns the display of the grid on or off.\n";
                text += "    Usage: grid on|off";
                return text;
            }
        }
    }
}
