﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace GameOfLife.Commands
{
    /// <summary>
    /// A command for displaying help information about the other commands in the system.
    /// </summary>
    internal class HelpCommand : Command
    {
        /// <summary>
        /// Gets or sets a list of all of the commands that the help command is aware of.
        /// </summary>
        public List<Command> Commands { get; set; }

        /// <summary>
        /// Returns the command name: help
        /// </summary>
        public string CommandText
        {
            get { return "help"; }
        }

        /// <summary>
        /// Executes the command, printing help information for all of the commands available.
        /// </summary>
        /// <param name="grid"></param>
        /// <param name="parameters"></param>
        /// <returns></returns>
        public bool Execute(Grid grid, string[] parameters)
        {
            Console.WriteLine("\n" + (Commands.Count + 2) + " commands available.\n");
            Console.WriteLine("exit:");
            Console.WriteLine("    Exits the program.");
            Console.WriteLine("    Usage: exit");
            Console.WriteLine();
            Console.WriteLine("start:");
            Console.WriteLine("    Begins animating.");
            Console.WriteLine("    Usage: start");
            Console.WriteLine();
            Console.WriteLine("help:");
            Console.WriteLine("    Shows this help.");
            Console.WriteLine("    Usage: help");
            Console.WriteLine();

            foreach (Command command in Commands)
            {
                Console.WriteLine(command.HelpText);
                Console.WriteLine();
            }

            return true;
        }

        /// <summary>
        /// Help text for the help command is... well... handled differently.
        /// </summary>
        public string HelpText
        {
            get
            {
                return "";
            }
        }
    }
}
